# Sonolus.py
Sonolus.py is a Python library for creating Sonolus engines.

## Installation
Sonolus.py is available on PyPI and can be installed using a package manager like pip.

=== "pip"
    ```bash
    pip install sonolus.py
    ```
=== "uv"
    ```bash
    uv add sonolus.py
    ```

## Getting Started
Coming soon!

## Documentation
See [Concepts](concepts/index.md) for an overview of usage details.

See [Reference](reference/index.md) for detailed information on classes and functions.
